==> quidproquo-actionprocessor-awslambda-0.0.200.tgz: package/lib/esm/getActionProcessor/core/event/apiGatwayEvent/api/transformResponseResult.js <==
import { EventActionType, actionResult, ErrorTypeEnum } from 'quidproquo-core';
import { qpqWebServerUtils } from 'quidproquo-webserver';
const ErrorTypeHttpResponseMap = {
    [ErrorTypeEnum.BadRequest]: 400,
    [ErrorTypeEnum.Unauthorized]: 401,
    [ErrorTypeEnum.PaymentRequired]: 402,
    [ErrorTypeEnum.Forbidden]: 403,
    [ErrorTypeEnum.NotFound]: 404,
    [ErrorTypeEnum.TimeOut]: 408,
    [ErrorTypeEnum.Conflict]: 409,
    [ErrorTypeEnum.UnsupportedMediaType]: 415,
    [ErrorTypeEnum.OutOfResources]: 500,
    [ErrorTypeEnum.GenericError]: 500,
    [ErrorTypeEnum.NotImplemented]: 501,
    [ErrorTypeEnum.NoContent]: 204,
    [ErrorTypeEnum.Invalid]: 422,
};
const transformHttpEventHeadersToAPIGatewayProxyResultHeaders = (headers) => {
    return Object.keys(headers)
        .filter((header) => !!headers[header])
        .reduce((acc, header) => ({ ...acc, [header]: headers[header] }), {});
};
const getResponseFromErrorResult = (error) => {
    const statusCode = ErrorTypeHttpResponseMap[error.errorType] || 500;
    return qpqWebServerUtils.toJsonEventResponse({
        errorType: error.errorType,
        errorText: error.errorText,
    }, statusCode);
};
const getProcessTransformResponseResult = (qpqConfig) => {
    // We might need to JSON.stringify the body.
    return async ({ eventParams, qpqEventRecordResponses }) => {
        const [apiGatewayEvent] = eventParams;
        const [record] = qpqEventRecordResponses;
        // If we have an error, we need to transform it to a response, otherwise we can just use the record as is
        const successRecord = record.success ? record.result : getResponseFromErrorResult(record.error);
        // Add the cors headers
        const currentHeaders = successRecord.headers || {};
        const headers = {
            ...qpqWebServerUtils.getCorsHeaders(qpqConfig, {}, currentHeaders),
            ...currentHeaders,
        };
        // Transform back to api gateway
        return actionResult({
            statusCode: successRecord.status,
            body: apiGatewayEvent.httpMethod === 'HEAD' || !successRecord.body ? '' : successRecord.body,
            isBase64Encoded: successRecord.isBase64Encoded,
            headers: transformHttpEventHeadersToAPIGatewayProxyResultHeaders(headers),
        });
    };
};
export default (qpqConfig) => {
    return {
        [EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
    };
};

==> quidproquo-actionprocessor-awslambda-0.0.204.tgz: package/lib/esm/getActionProcessor/core/event/apiGatwayEvent/api/transformResponseResult.js <==
import { EventActionType, actionResult, ErrorTypeEnum } from 'quidproquo-core';
import { qpqWebServerUtils } from 'quidproquo-webserver';
const ErrorTypeHttpResponseMap = {
    [ErrorTypeEnum.BadRequest]: 400,
    [ErrorTypeEnum.Unauthorized]: 401,
    [ErrorTypeEnum.PaymentRequired]: 402,
    [ErrorTypeEnum.Forbidden]: 403,
    [ErrorTypeEnum.NotFound]: 404,
    [ErrorTypeEnum.TimeOut]: 408,
    [ErrorTypeEnum.Conflict]: 409,
    [ErrorTypeEnum.UnsupportedMediaType]: 415,
    [ErrorTypeEnum.OutOfResources]: 500,
    [ErrorTypeEnum.GenericError]: 500,
    [ErrorTypeEnum.NotImplemented]: 501,
    [ErrorTypeEnum.NoContent]: 204,
    [ErrorTypeEnum.Invalid]: 422,
};
const transformHttpEventHeadersToAPIGatewayProxyResultHeaders = (headers) => {
    return Object.keys(headers)
        .filter((header) => !!headers[header])
        .reduce((acc, header) => ({ ...acc, [header]: headers[header] }), {});
};
const getResponseFromErrorResult = (error) => {
    const statusCode = ErrorTypeHttpResponseMap[error.errorType] || 500;
    return qpqWebServerUtils.toJsonEventResponse({
        errorType: error.errorType,
        errorText: error.errorText,
    }, statusCode);
};
const getProcessTransformResponseResult = (qpqConfig) => {
    // We might need to JSON.stringify the body.
    return async ({ eventParams, qpqEventRecordResponses }) => {
        const [apiGatewayEvent] = eventParams;
        const [record] = qpqEventRecordResponses;
        // If we have an error, we need to transform it to a response, otherwise we can just use the record as is
        const successRecord = record.success ? record.result : getResponseFromErrorResult(record.error);
        // Add the cors headers
        const currentHeaders = successRecord.headers || {};
        const headers = {
            ...qpqWebServerUtils.getCorsHeaders(qpqConfig, {}, apiGatewayEvent.headers),
            ...currentHeaders,
        };
        // Transform back to api gateway
        return actionResult({
            statusCode: successRecord.status,
            body: apiGatewayEvent.httpMethod === 'HEAD' || !successRecord.body ? '' : successRecord.body,
            isBase64Encoded: successRecord.isBase64Encoded,
            headers: transformHttpEventHeadersToAPIGatewayProxyResultHeaders(headers),
        });
    };
};
export default (qpqConfig) => {
    return {
        [EventActionType.TransformResponseResult]: getProcessTransformResponseResult(qpqConfig),
    };
};
